#
# spec file for package ncmpcpp
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           ncmpcpp
Version:        0.9.2
Release:        3.9
Summary:        Music Player Daemon Client
License:        GPL-2.0-only
Group:          Productivity/Multimedia/Sound/Players
URL:            https://rybczak.net/ncmpcpp
Source:         https://github.com/ncmpcpp/ncmpcpp/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM
Patch0:         0001-Fix-compilation-with-taglib-2.0.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  curl-devel
BuildRequires:  fftw-devel
BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  libboost_filesystem-devel
BuildRequires:  libboost_headers-devel
BuildRequires:  libboost_locale-devel
BuildRequires:  libboost_program_options-devel
BuildRequires:  libboost_regex-devel
BuildRequires:  libboost_system-devel
BuildRequires:  libboost_thread-devel
BuildRequires:  libtag-devel
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(libmpdclient)
BuildRequires:  pkgconfig(ncursesw)
BuildRequires:  pkgconfig(readline)
Requires:       mpd > 0.16

%description
ncmpcpp is an ncurses client for MPD (Music Player Daemon), inspired
by ncmpc. It features a tag editor, playlist editor, search engine,
media library, music visualizer, a last.fm artist database
information fetcher and an alternative user interface.

%prep
%autosetup -p1

%build
autoreconf -fiv
%configure \
  --enable-clock \
  --enable-outputs \
  --enable-visualizer
%make_build

%install
%make_install
rm -r "%{buildroot}%{_datadir}/doc"

%files
%license COPYING
%doc AUTHORS CHANGELOG.md doc/config doc/bindings
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1%{?ext_man}

%changelog
* Thu Mar 21 2024 Christophe Marin <christophe@krop.fr>
- Add upstream change to fix build with taglib 2.0:
  * 0001-Fix-compilation-with-taglib-2.0.patch
* Sun Sep 26 2021 Avindra Goolcharan <avindra@opensuse.org>
- pass --enable-outputs to configure
* Sun Feb 28 2021 Dirk Müller <dmueller@suse.com>
- update to 0.9.2:
  * Revert suppression of output of all external commands as that makes e.g
    album art addons no longer work.
  * Gracefully handle failures when asking for a password.
* Sat Dec 26 2020 Avindra Goolcharan <avindra@opensuse.org>
- Update to 0.9.1
- update url to org repo
- remove upstreamed fix_gcc10_error.patch
* Tue Nov 17 2020 kujiu-obs@kujiu.org
- Fix build error with gcc 10
  * Patch according to this commit : https://github.com/ncmpcpp/ncmpcpp/commit/399e0f47008b487df3505476c959b4f42d8bc1b1
* Wed Apr 11 2018 avindra@opensuse.org
- Update to 0.8.2
  * Help screen: fixed display of EoF keycode
  * Fixed possible integer overflow when resizing screen
  * Fixed fetching lyrics from lyricsmania.com, metrolyrics.com
    and sing365.com
  * Search engine now properly interacts with filtering
  * Fixed redraw of separator after interface switch while MPD was
    stopped
  * Reset position of a window when fetching lyrics
  * Fixed compilation with ICU >= 61.
- cleanup with spec-cleaner
* Wed Jan 31 2018 olaf@aepfle.de
- Adjust usage of gccN for Leap42 and SLE12
* Thu Dec 28 2017 jengelh@inai.de
- Update description.
* Fri Oct 20 2017 aavindraa@gmail.com
- Update to 0.8.1
  * Curl: re-enable verification of SSL certificate against host
* Sun Aug  6 2017 mpluskal@suse.com
- Cleanup spec file with spe-cleaner
- Resolve building on Leap
* Sun Jul 30 2017 sogal@volted.net
- Initial build as ncmpcpp is not in Packman repo for Leap 42.3
